# Contributing to usenc

See our [Contributing Guide](https://crashoz.github.io/usenc/development/contributing/) for details.

## Quick Start
1. Fork and clone
2. Install dev dependencies: `pip install -e ".[dev]"`
3. Install pre-commit: `pre-commit install`
4. Make changes and run tests: `pytest`
5. Submit PR
